aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/qml/Qt6QmlMacros.cmake22
-rw-r--r--tests/auto/qml/qmltyperegistrar/CMakeLists.txt2
-rw-r--r--tests/auto/qml/qqmlanybinding/CMakeLists.txt2
-rw-r--r--tests/auto/qml/qqmlbinding/CMakeLists.txt2
-rw-r--r--tests/auto/qml/qqmlinfo/CMakeLists.txt2
-rw-r--r--tests/auto/qml/qqmllanguage/CMakeLists.txt2
-rw-r--r--tests/auto/qml/qqmlproperty/CMakeLists.txt2
-rw-r--r--tests/auto/qml/qqmltypeloader/CMakeLists.txt2
-rw-r--r--tests/auto/qml/registrationmacros/CMakeLists.txt2
-rw-r--r--tests/auto/quick/qquickbehaviors/CMakeLists.txt2
10 files changed, 23 insertions, 17 deletions
diff --git a/tests/auto/qml/qmltyperegistrar/CMakeLists.txt b/tests/auto/qml/qmltyperegistrar/CMakeLists.txt
index bc00560cca..101b13cbb0 100644
--- a/tests/auto/qml/qmltyperegistrar/CMakeLists.txt
+++ b/tests/auto/qml/qmltyperegistrar/CMakeLists.txt
@@ -44,5 +44,5 @@ set_target_properties(tst_qmltyperegistrar PROPERTIES
# qt6_add_qml_module() doesn't allow us to pass through MANUAL_MOC_JSON_FILES
# yet, so we have to call it directly to test that code path for now.
-qt6_qml_type_registration(tst_qmltyperegistrar MANUAL_MOC_JSON_FILES ${json_list})
+_qt_internal_qml_type_registration(tst_qmltyperegistrar MANUAL_MOC_JSON_FILES ${json_list})
add_subdirectory(foreign)
diff --git a/tests/auto/qml/qqmlanybinding/CMakeLists.txt b/tests/auto/qml/qqmlanybinding/CMakeLists.txt
index 83c9bd7994..926a230bb3 100644
--- a/tests/auto/qml/qqmlanybinding/CMakeLists.txt
+++ b/tests/auto/qml/qqmlanybinding/CMakeLists.txt
@@ -29,7 +29,7 @@ set_target_properties(tst_qqmlanybinding PROPERTIES
QT_QML_MODULE_URI bindable
)
-qt6_qml_type_registration(tst_qqmlanybinding)
+_qt_internal_qml_type_registration(tst_qqmlanybinding)
## Scopes:
#####################################################################
diff --git a/tests/auto/qml/qqmlbinding/CMakeLists.txt b/tests/auto/qml/qqmlbinding/CMakeLists.txt
index 6bf1668970..eeb9f391e3 100644
--- a/tests/auto/qml/qqmlbinding/CMakeLists.txt
+++ b/tests/auto/qml/qqmlbinding/CMakeLists.txt
@@ -31,7 +31,7 @@ set_target_properties(tst_qqmlbinding PROPERTIES
QT_QML_MODULE_VERSION 1.0
)
-qt6_qml_type_registration(tst_qqmlbinding)
+_qt_internal_qml_type_registration(tst_qqmlbinding)
## Scopes:
diff --git a/tests/auto/qml/qqmlinfo/CMakeLists.txt b/tests/auto/qml/qqmlinfo/CMakeLists.txt
index 4d234e8ce0..9a66dd0728 100644
--- a/tests/auto/qml/qqmlinfo/CMakeLists.txt
+++ b/tests/auto/qml/qqmlinfo/CMakeLists.txt
@@ -47,4 +47,4 @@ set_target_properties(tst_qqmlinfo PROPERTIES
QT_QML_MODULE_URI org.qtproject.Test
)
-qt6_qml_type_registration(tst_qqmlinfo)
+_qt_internal_qml_type_registration(tst_qqmlinfo)
diff --git a/tests/auto/qml/qqmllanguage/CMakeLists.txt b/tests/auto/qml/qqmllanguage/CMakeLists.txt
index e7fa05d23e..372e6086ed 100644
--- a/tests/auto/qml/qqmllanguage/CMakeLists.txt
+++ b/tests/auto/qml/qqmllanguage/CMakeLists.txt
@@ -67,4 +67,4 @@ set_target_properties(tst_qqmllanguage PROPERTIES
QT_QML_MODULE_URI StaticTest
)
-qt6_qml_type_registration(tst_qqmllanguage)
+_qt_internal_qml_type_registration(tst_qqmllanguage)
diff --git a/tests/auto/qml/qqmlproperty/CMakeLists.txt b/tests/auto/qml/qqmlproperty/CMakeLists.txt
index 2dabf0f948..21f4372058 100644
--- a/tests/auto/qml/qqmlproperty/CMakeLists.txt
+++ b/tests/auto/qml/qqmlproperty/CMakeLists.txt
@@ -47,4 +47,4 @@ set_target_properties(tst_qqmlproperty PROPERTIES
QT_QML_MODULE_URI io.qt.bugreports
)
-qt6_qml_type_registration(tst_qqmlproperty)
+_qt_internal_qml_type_registration(tst_qqmlproperty)
diff --git a/tests/auto/qml/qqmltypeloader/CMakeLists.txt b/tests/auto/qml/qqmltypeloader/CMakeLists.txt
index b56dbd8944..8c16b922e4 100644
--- a/tests/auto/qml/qqmltypeloader/CMakeLists.txt
+++ b/tests/auto/qml/qqmltypeloader/CMakeLists.txt
@@ -56,5 +56,5 @@ set_target_properties(tst_qqmltypeloader PROPERTIES
QT_QML_MODULE_URI declarative.import.for.typeloader.test
)
-qt6_qml_type_registration(tst_qqmltypeloader)
+_qt_internal_qml_type_registration(tst_qqmltypeloader)
add_subdirectory(SlowImport)
diff --git a/tests/auto/qml/registrationmacros/CMakeLists.txt b/tests/auto/qml/registrationmacros/CMakeLists.txt
index 6ac5d4506c..3e01ae34c8 100644
--- a/tests/auto/qml/registrationmacros/CMakeLists.txt
+++ b/tests/auto/qml/registrationmacros/CMakeLists.txt
@@ -14,4 +14,4 @@ set_target_properties(tst_registrationmacros PROPERTIES
QT_QML_MODULE_URI test
)
-qt6_qml_type_registration(tst_registrationmacros)
+_qt_internal_qml_type_registration(tst_registrationmacros)
diff --git a/tests/auto/quick/qquickbehaviors/CMakeLists.txt b/tests/auto/quick/qquickbehaviors/CMakeLists.txt
index b864b0c21b..e75d0b7973 100644
--- a/tests/auto/quick/qquickbehaviors/CMakeLists.txt
+++ b/tests/auto/quick/qquickbehaviors/CMakeLists.txt
@@ -31,7 +31,7 @@ set_target_properties(tst_qquickbehaviors PROPERTIES
QT_QML_MODULE_URI test
)
-qt6_qml_type_registration(tst_qquickbehaviors)
+_qt_internal_qml_type_registration(tst_qquickbehaviors)
#### Keys ignored in scope 1:.:.:qquickbehaviors.pro:<TRUE>:
diff --git a/src/qml/Qt6QmlMacros.cmake b/src/qml/Qt6QmlMacros.cmake
index 83161a50ee..4c4186025e 100644
--- a/src/qml/Qt6QmlMacros.cmake
+++ b/src/qml/Qt6QmlMacros.cmake
@@ -21,7 +21,7 @@ function(qt6_add_qml_module target)
# TODO: Remove once all usages have also been removed
SKIP_TYPE_REGISTRATION
# Used only by qt6_qml_type_registration()
# TODO: Remove this once qt6_extract_metatypes does not install by default.
__QT_INTERNAL_INSTALL_METATYPES_JSON
)
@@ -442,7 +442,7 @@ function(qt6_add_qml_module target)
if(arg___QT_INTERNAL_INSTALL_METATYPES_JSON)
list(APPEND type_registration_extra_args __QT_INTERNAL_INSTALL_METATYPES_JSON)
endif()
- qt6_qml_type_registration(${target} ${type_registration_extra_args})
+ _qt_internal_qml_type_registration(${target} ${type_registration_extra_args})
endif()
set(output_targets)
@@ -1585,10 +1585,6 @@ if(NOT QT_NO_CREATE_VERSIONLESS_FUNCTIONS)
endfunction()
endif()
-# NOTE: This function does not normally need to be called directly by projects.
-# It is called automatically by qt6_add_qml_module() unless
-# NO_GENERATE_QMLTYPES is also given to that function.
-#
# target: Expected to be the backing target for a qml module. Certain target
# properties normally set by qt6_add_qml_module() will be retrieved from this
# target. (REQUIRED)
@@ -1596,7 +1592,7 @@ endif()
# MANUAL_MOC_JSON_FILES: Specifies a list of json files, generated by a manual
# moc call, to extract metatypes. (OPTIONAL)
#
-function(qt6_qml_type_registration target)
+function(_qt_internal_qml_type_registration target)
set(args_option __QT_INTERNAL_INSTALL_METATYPES_JSON)
set(args_single "")
set(args_multi MANUAL_MOC_JSON_FILES)
@@ -1819,9 +1815,19 @@ function(qt6_qml_type_registration target)
)
endfunction()
+function(qt6_qml_type_registration)
+ message(FATAL_ERROR
+ "This function, previously available under Technical Preview, has been removed. "
+ "Please use qt6_add_qml_module() instead."
+ )
+endfunction()
+
if(NOT QT_NO_CREATE_VERSIONLESS_FUNCTIONS)
function(qt_qml_type_registration)
- qt6_qml_type_registration(${ARGV})
+ message(FATAL_ERROR
+ "This function, previously available under Technical Preview, has been removed. "
+ "Please use qt_add_qml_module() instead."
+ )
endfunction()
endif()
@@ -21,7 +21,7 @@ function(qt6_add_qml_module target)
# TODO: Remove once all usages have also been removed
SKIP_TYPE_REGISTRATION
- # Used only by qt6_qml_type_registration()
+ # Used only by _qt_internal_qml_type_registration()
# TODO: Remove this once qt6_extract_metatypes does not install by default.
__QT_INTERNAL_INSTALL_METATYPES_JSON